==> glog-2.60.tar.gz: glog-2.60/comments.xml.php <==
<?php
# RSS 2.0 comments exporter
#
# $Id: comments.xml.php,v 1.2 2005/04/28 16:59:56 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("config.php");
	include(LIB_DIR . "funcs.php");

	header("Content-type: text/xml; charset=windows-1251");
	print '<' . '?xml version="1.0" encoding="windows-1251"?>';

	$last_comments = load_last_comments();
	$total_comments = count($last_comments);
	$last_comment_ts = 0;
	if ($total_comments) {
		$last_comment_ts = next($last_comments);
		reset($last_comments);
	}
?>
<rss version="2.0" 
	xmlns:content="http://purl.org/rss/1.0/modules/content/">

<channel>
	<title><?=BLOG_TITLE?> /  <?=FEEDS_COMMENTS?> </title>
	<link>http://<?=HOST?><?=BASEDIR?></link>
	<description> <?=FEEDS_COMMENTS?>   <?=BLOG_TITLE?></description>
	<language>bg</language>
	<copyright>Copyright (c) <?=AUTHOR_EMAIL?></copyright>
	<generator>http://georgi.unixsol.org/programs/glog/</generator>
	<pubDate><?=date("r", $last_comment_ts)?></pubDate>
<?
	if ($total_comments) {
		foreach($last_comments as $id => $line) {
			@list($ts, $date) = split(" ",$id);
			@list($published, $ip, $proxy, $ua, $author, $email, $url, $text) = split("\t", $line);
			$text = format_comment($text);
?>
	<item>
		<title>  <?=htmlspecialchars($author)?></title>
		<link>http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?>#<?=$published?></link>
		<pubDate><?=date("r",$published)?></pubDate>
		<guid isPermaLink="true">http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?>#<?=$published?></guid>
		<description><![CDATA[ <p><?=nl2br(htmlspecialchars($text))?></p> ]]></description>
		<content:encoded><![CDATA[ <p><?=nl2br(htmlspecialchars($text))?></p> ]]></content:encoded>
	</item>
<?
		}
	}
?>
</channel>
</rss>

==> glog-2.70.tar.gz: glog-2.70/comments.xml.php <==
<?php
# RSS 2.0 comments exporter
#
# $Id: comments.xml.php,v 1.3 2005/05/26 20:58:02 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("config.php");
	include(LIB_DIR . "funcs.php");

	header("Content-type: text/xml; charset=windows-1251");
	print '<' . '?xml version="1.0" encoding="windows-1251"?>';

	$last_comments = load_last_comments();
	$total_comments = count($last_comments);
	$last_comment_ts = 0;
	if ($total_comments) {
		$last_comment_ts = next($last_comments);
		reset($last_comments);
	}
?>
<rss version="2.0" 
	xmlns:content="http://purl.org/rss/1.0/modules/content/">

<channel>
	<title><?=BLOG_TITLE?> /  <?=FEEDS_COMMENTS?> </title>
	<link>http://<?=HOST?><?=BASEDIR?></link>
	<description> <?=FEEDS_COMMENTS?>   <?=BLOG_TITLE?></description>
	<language>bg</language>
	<copyright>Copyright (c) <?=AUTHOR_EMAIL?></copyright>
	<generator>http://georgi.unixsol.org/programs/glog/</generator>
	<pubDate><?=date("r", $last_comment_ts)?></pubDate>
<?
	if ($total_comments) {
		foreach($last_comments as $id => $line) {
			@list($ts, $date) = split(" ",$id);
			@list($published, $ip, $proxy, $ua, $author, $email, $url, $text) = split("\t", $line);
			$text = format_comment($text);
?>
	<item>
		<title>  <?=htmlspecialchars($author)?></title>
		<link>http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?>#<?=$published?></link>
		<pubDate><?=date("r",$published)?></pubDate>
		<guid isPermaLink="true">http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?>#<?=$published?></guid>
		<description><![CDATA[<p><?=$text?></p>]]></description>
		<content:encoded><![CDATA[<p><?=$text?></p>]]></content:encoded>
	</item>
<?
		}
	}
?>
</channel>
</rss>
